Rebuilder

Type Alias Rebuilder 

pub type Rebuilder<P> = Arc<dyn Fn(&GatewayConfig) -> Result<ProviderRegistry<P>, Error> + Send + Sync>;
A closure that rebuilds the provider registry from a config. The binary provides this because the proxy crate doesn’t know the concrete P construction path (e.g. Dispatch::Remote).

Aliased Type

pub struct Rebuilder<P> { /* private fields */ }